@@ -13,7 +13,7 @@
 import logging
 
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from openstack_dashboard.api import base
 from watcherclient import client as wc
 
