@@ -16,9 +16,9 @@
 from django import shortcuts
 from django.template.defaultfilters import title  # noqa
 from django import urls
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 from django.utils.translation import pgettext_lazy
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
 import horizon.exceptions
 import horizon.messages
 import horizon.tables
@@ -88,7 +88,7 @@ class ArchiveAudits(horizon.tables.DeleteAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Archive Audit",
             "Archive Audits",
             count
@@ -96,7 +96,7 @@ class ArchiveAudits(horizon.tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Archived Audit",
             "Archived Audits",
             count
